@@ -1,5 +1,4 @@
 import warnings
-from itertools import permutations
 
 import geopandas
 import numpy as np
@@ -10,9 +9,28 @@ from packaging.version import Version
 GPD_013 = Version(geopandas.__version__) >= Version("0.13")
 PANDAS_GE_21 = Version(pd.__version__) >= Version("2.1.0")
 
+try:
+    from numba import njit  # noqa: E401
 
-def _sparse_to_arrays(sparray, ids=None):
-    """Convert sparse array to arrays of adjacency"""
+    HAS_NUMBA = True
+except ModuleNotFoundError:
+    from libpysal.common import jit as njit
+
+    HAS_NUMBA = False
+
+
+class CoplanarError(ValueError):
+    """Custom ValueError raised when coplanar points are detected."""
+
+    pass
+
+
+def _sparse_to_arrays(sparray, ids=None, resolve_isolates=True, return_adjacency=False):
+    """Convert sparse array to arrays of adjacency
+
+    When we know we are dealing with cliques, we don't want to resolve
+    isolates here but will do that later once cliques are induced.
+    """
     sparray = sparray.tocoo(copy=False)
     if ids is not None:
         ids = np.asarray(ids)
@@ -32,10 +50,23 @@ def _sparse_to_arrays(sparray, ids=None):
         tail = sparray.col[sorter]
         data = sparray.data[sorter]
         ids = np.arange(sparray.shape[0], dtype=int)
-    return _resolve_islands(head, tail, ids, data)
+
+    if resolve_isolates:
+        return _resolve_islands(
+            head, tail, ids, data, return_adjacency=return_adjacency
+        )
+
+    if return_adjacency:
+        return pd.Series(
+            data,
+            index=pd.MultiIndex.from_arrays([head, tail], names=["focal", "neighbor"]),
+            name="weight",
+        )
+
+    return head, tail, data
 
 
-def _jitter_geoms(coordinates, geoms, seed=None):
+def _jitter_geoms(coordinates, geoms=None, seed=None):
     """
     Jitter geometries based on the smallest required movements to induce
     uniqueness. For each point, this samples a radius and angle uniformly
@@ -61,11 +92,16 @@ def _jitter_geoms(coordinates, geoms, seed=None):
     dy = r + np.cos(theta)
     # then adding the displacements
     coordinates = coordinates + np.column_stack((dx, dy))
-    geoms = geopandas.GeoSeries(geopandas.points_from_xy(*coordinates.T, crs=geoms.crs))
-    return coordinates, geoms
+    if geoms is not None:
+        geoms = geopandas.GeoSeries(
+            geopandas.points_from_xy(*coordinates.T, crs=geoms.crs)
+        )
+        return coordinates, geoms
+
+    return coordinates
 
 
-def _induce_cliques(adjtable, clique_to_members, fill_value=1):
+def _induce_cliques(adjtable, coplanar, nearest, fill_value=1):
     """
     induce cliques into the input graph. This connects everything within a
     clique together, as well as connecting all things outside of the clique
@@ -73,34 +109,25 @@ def _induce_cliques(adjtable, clique_to_members, fill_value=1):
 
     This does not guarantee/understand ordering of the *output* adjacency table.
     """
-    adj_across_clique = (
-        adjtable.merge(
-            clique_to_members["input_index"], left_on="focal", right_index=True
-        )
-        .explode("input_index")
-        .rename(columns={"input_index": "subclique_focal"})
-        .merge(clique_to_members["input_index"], left_on="neighbor", right_index=True)
-        .explode("input_index")
-        .rename(columns={"input_index": "subclique_neighbor"})
-        .reset_index()
-        .drop(["focal", "neighbor", "index"], axis=1)
-        .rename(columns={"subclique_focal": "focal", "subclique_neighbor": "neighbor"})
-    )[["focal", "neighbor", "weight"]]
-    is_multimember_clique = clique_to_members["input_index"].str.len() > 1
-    adj_within_clique = (
-        clique_to_members[is_multimember_clique]["input_index"]
-        .apply(lambda x: list(permutations(x, 2)))
-        .explode()
-        .apply(pd.Series)
-        .rename(columns={0: "focal", 1: "neighbor"})
-        .assign(weight=fill_value)
+    coplanar_addition = []
+    for c, n in zip(coplanar, nearest, strict=True):
+        neighbors = adjtable.neighbor[adjtable.focal == n]
+        for n_ in neighbors:
+            fill = adjtable.weight[
+                (adjtable.focal == n) & (adjtable.neighbor == n_)
+            ].item()
+            coplanar_addition.append([c, n_, fill])
+            coplanar_addition.append([n_, c, fill])
+        coplanar_addition.append([c, n, fill_value])
+        coplanar_addition.append([n, c, fill_value])
+    adjtable_filled = pd.concat(
+        [
+            adjtable,
+            pd.DataFrame(coplanar_addition, columns=["focal", "neighbor", "weight"]),
+        ],
+        ignore_index=True,
     )
-
-    new_adj = pd.concat(
-        (adj_across_clique, adj_within_clique), ignore_index=True, axis=0
-    ).reset_index(drop=True)
-
-    return new_adj
+    return adjtable_filled
 
 
 def _neighbor_dict_to_edges(neighbors, weights=None):
@@ -109,13 +136,15 @@ def _neighbor_dict_to_edges(neighbors, weights=None):
     that the any self-loops have a weight of zero.
     """
     idxs = pd.Series(neighbors).explode()
-    with warnings.catch_warnings():
-        warnings.filterwarnings(
-            "ignore",
-            "Downcasting object dtype arrays on .fillna, .ffill, .bfill ",
-            FutureWarning,
-        )
-        idxs = idxs.fillna(pd.Series(idxs.index, index=idxs.index))  # self-loops
+    isolates = idxs.isna()
+    if isolates.any():
+        with warnings.catch_warnings():
+            warnings.filterwarnings(
+                "ignore",
+                "Downcasting object dtype arrays on .fillna, .ffill, .bfill ",
+                FutureWarning,
+            )
+            idxs = idxs.fillna(pd.Series(idxs.index, index=idxs.index))  # self-loops
     heads, tails = idxs.index.values, idxs.values
     tails = tails.astype(heads.dtype)
     if weights is not None:
@@ -130,42 +159,27 @@ def _neighbor_dict_to_edges(neighbors, weights=None):
             data_array = pd.to_numeric(data_array)
     else:
         data_array = np.ones(idxs.shape[0], dtype=int)
-        data_array[heads == tails] = 0
+        data_array[isolates.values] = 0
     return heads, tails, data_array
 
 
-def _build_coincidence_lookup(geoms):
+def _build_coplanarity_lookup(geoms):
     """
-    Identify coincident points and create a look-up table for the coincident geometries.
+    Identify coplanar points and create a look-up table for the coplanar geometries.
     """
-    valid_coincident_geom_types = set(("Point",))  # noqa: C405
-    if not set(geoms.geom_type) <= valid_coincident_geom_types:
-        raise ValueError(
-            "coindicence checks are only well-defined for "
-            f"geom_types: {valid_coincident_geom_types}"
-        )
-    max_coincident = geoms.geometry.duplicated().sum()
-    if GPD_013:
-        lut = (
-            geoms.to_frame("geometry")
-            .reset_index()
-            .groupby("geometry")["index"]
-            .agg(list)
-            .reset_index()
-        )
-    else:
-        lut = (
-            geoms.to_wkb()
-            .to_frame("geometry")
-            .reset_index()
-            .groupby("geometry")["index"]
-            .agg(list)
-            .reset_index()
-        )
-        lut["geometry"] = geopandas.GeoSeries.from_wkb(lut["geometry"])
-
-    lut = geopandas.GeoDataFrame(lut)
-    return max_coincident, lut.rename(columns={"index": "input_index"})
+    geoms = geoms.reset_index(drop=True)
+    coplanar = []
+    nearest = []
+    r = geoms.groupby(geoms).groups if GPD_013 else geoms.groupby(geoms.to_wkb()).groups
+    for g in r.values():
+        if len(g) == 2:
+            coplanar.append(g[0])
+            nearest.append(g[1])
+        elif len(g) > 2:
+            for n in g[1:]:
+                coplanar.append(n)
+                nearest.append(g[0])
+    return np.asarray(coplanar), np.asarray(nearest)
 
 
 def _validate_geometry_input(geoms, ids=None, valid_geometry_types=None):
@@ -218,13 +232,6 @@ def _validate_geometry_input(geoms, ids=None, valid_geometry_types=None):
     )
 
 
-def _validate_sparse_input(sparse, ids=None):
-    assert (
-        sparse.shape[0] == sparse.shape[1]
-    ), "coordinates should represent a distance matrix if metric='precomputed'"
-    return _sparse_to_arrays(sparse, ids)
-
-
 def _vec_euclidean_distances(x_vec, y_vec):
     """
     compute the euclidean distances along corresponding rows of two arrays
@@ -242,7 +249,7 @@ def _evaluate_index(data):
         return pd.RangeIndex(0, len(data))
 
 
-def _resolve_islands(heads, tails, ids, weights):
+def _resolve_islands(heads, tails, ids, weights, return_adjacency=False):
     """
     Induce self-loops for a collection of ids and links describing a
     contiguity graph. Induced self-loops will have zero weight.
@@ -254,8 +261,14 @@ def _resolve_islands(heads, tails, ids, weights):
         weights = np.hstack((weights, np.zeros_like(islands, dtype=int)))
 
     # ensure proper order after adding isolates to the end
-    adjacency = pd.Series(weights, index=pd.MultiIndex.from_arrays([heads, tails]))
+    adjacency = pd.Series(
+        weights,
+        index=pd.MultiIndex.from_arrays([heads, tails], names=["focal", "neighbor"]),
+        name="weight",
+    )
     adjacency = adjacency.reindex(ids, level=0).reindex(ids, level=1)
+    if return_adjacency:
+        return adjacency
     return (
         adjacency.index.get_level_values(0),
         adjacency.index.get_level_values(1),
@@ -264,20 +277,113 @@ def _resolve_islands(heads, tails, ids, weights):
 
 
 def _reorder_adjtable_by_ids(adjtable, ids):
-    if PANDAS_GE_21:
-        # ensure proper sorting
-        sorted_index = (
-            adjtable[["focal", "neighbor"]]
-            .map(list(ids).index)
-            .sort_values(["focal", "neighbor"])
-            .index
-        )
+    return (
+        adjtable.set_index(["focal", "neighbor"])
+        .reindex(ids, level=0)
+        .reindex(ids, level=1)
+        .reset_index()
+    )
+
+
+@njit
+def _mode(values, index):  # noqa: ARG001
+    """Custom mode function for numba."""
+    array = np.sort(values.ravel())
+    mask = np.empty(array.shape, dtype=np.bool_)
+    mask[:1] = True
+    mask[1:] = array[1:] != array[:-1]
+    unique = array[mask]
+    idx = np.nonzero(mask)[0]
+    idx = np.append(idx, mask.size)
+    counts = np.diff(idx)
+    return unique[np.argmax(counts)]
+
+
+@njit
+def _limit_range(values, index, low, high):  # noqa: ARG001
+    nan_tracker = np.isnan(values)
+
+    if (not nan_tracker.all()) & (len(values[~nan_tracker]) > 2):
+        lower, higher = np.nanpercentile(values, (low, high))
     else:
-        # ensure proper sorting
-        sorted_index = (
-            adjtable[["focal", "neighbor"]]
-            .applymap(list(ids).index)
-            .sort_values(["focal", "neighbor"])
-            .index
+        return ~nan_tracker
+
+    return (lower <= values) & (values <= higher)
+
+
+def _compute_stats(grouper, to_compute: list[str] | None = None):
+    """Fast compute of "count", "mean", "median", "std", "min", "max", \\
+    "sum", "nunique" and "mode" within a grouper object. Using numba.
+
+    Parameters
+    ----------
+    grouper : pandas.GroupBy
+        Groupby Object which specifies the aggregations to be performed.
+    to_compute : list[str]
+        A list of stats functions to pass to groupby.agg
+
+    Returns
+    -------
+    DataFrame
+    """
+
+    if not HAS_NUMBA:
+        warnings.warn(
+            "The numba package is used extensively in this module"
+            " to accelerate the computation of graphs. Without numba,"
+            " these computations may become unduly slow on large data.",
+            stacklevel=3,
         )
-    return adjtable.iloc[sorted_index].reset_index(drop=True)
+
+    if to_compute is None:
+        to_compute = [
+            "count",
+            "mean",
+            "median",
+            "std",
+            "min",
+            "max",
+            "sum",
+            "nunique",
+            "mode",
+        ]
+    agg_to_compute = [f for f in to_compute if f != "mode"]
+    stat_ = grouper.agg(agg_to_compute)
+    if "mode" in to_compute:
+        if HAS_NUMBA:
+            stat_["mode"] = grouper.agg(_mode, engine="numba")
+        else:
+            stat_["mode"] = grouper.agg(lambda x: _mode(x.values, x.index))
+
+    return stat_
+
+
+def _percentile_filtration_grouper(y, graph_adjacency_index, q=(25, 75)):
+    """Carry out a filtration of graph neighbours \\
+        based on the quantiles of  ``y``, specified in ``q``"""
+    if not HAS_NUMBA:
+        warnings.warn(
+            "The numba package is used extensively in this module"
+            " to accelerate the computation of graphs. Without numba,"
+            " these computations may become unduly slow on large data.",
+            stacklevel=3,
+        )
+
+    ## need to reset since numba transform has an indexing issue
+    grouper = (
+        y.take(graph_adjacency_index.codes[-1])
+        .reset_index(drop=True)
+        .groupby(graph_adjacency_index.codes[0])
+    )
+    if HAS_NUMBA:
+        to_keep = grouper.transform(
+            _limit_range, q[0], q[1], engine="numba"
+        ).values.astype(bool)
+    else:
+        to_keep = grouper.transform(
+            lambda x: _limit_range(x.values, x.index, q[0], q[1])
+        ).values.astype(bool)
+    filtered_grouper = y.take(graph_adjacency_index.codes[-1][to_keep]).groupby(
+        graph_adjacency_index.codes[0][to_keep]
+    )
+    return filtered_grouper
