@@ -3,6 +3,8 @@ from functools import cached_property
 
 import numpy as np
 import pandas as pd
+from packaging.version import Version
+from scipy import __version__ as scipy_version
 from scipy import sparse
 
 from libpysal.weights import W
@@ -14,19 +16,24 @@ from ._contiguity import (
     _rook,
     _vertex_set_intersection,
 )
+from ._indices import _build_from_h3
 from ._kernel import _distance_band, _kernel
 from ._matching import _spatial_matching
-from ._parquet import _read_parquet, _to_parquet
 from ._plotting import _explore_graph, _plot
 from ._set_ops import SetOpsMixin
 from ._spatial_lag import _lag_spatial
 from ._triangulation import _delaunay, _gabriel, _relative_neighborhood, _voronoi
 from ._utils import (
+    _compute_stats,
     _evaluate_index,
     _neighbor_dict_to_edges,
+    _percentile_filtration_grouper,
     _resolve_islands,
     _sparse_to_arrays,
 )
+from .io._gal import _read_gal, _to_gal
+from .io._gwt import _read_gwt, _to_gwt
+from .io._parquet import _read_parquet, _to_parquet
 
 ALLOWED_TRANSFORMATIONS = ("O", "B", "R", "D", "V", "C")
 
@@ -38,6 +45,13 @@ Serge Rey (sjsrey@gmail.com)
 Levi John Wolf (levi.john.wolf@gmail.com)
 """
 
+__all__ = [
+    "Graph",
+    "read_parquet",
+    "read_gal",
+    "read_gwt",
+]
+
 
 class Graph(SetOpsMixin):
     """Graph class encoding spatial weights matrices
@@ -75,16 +89,17 @@ class Graph(SetOpsMixin):
             initialize the class. The MultiIndex needs to be ordered i-->j
             on both focal and neighbor levels according to the order of ids in the
             original data from which the Graph is created. Sorting is performed by
-            default based on the order of unique values in the focal level. Set
-            ``is_sorted=True`` to skip this step if the adjacency is already canonically
-            sorted.
+            default based on the order of unique values in the focal level. Sorting
+            needs to be reflected in both the values of the MultiIndex and also the
+            underlying MultiIndex.codes. Set ``is_sorted=True`` to skip this step if the
+            adjacency is already canonically sorted and you are certain about it.
 
         """
         if not isinstance(adjacency, pd.Series):
             raise TypeError(
                 f"The adjacency table needs to be a pandas.Series. {type(adjacency)}"
             )
-        if not adjacency.index.names == ["focal", "neighbor"]:
+        if not tuple(adjacency.index.names) == ("focal", "neighbor"):
             raise ValueError(
                 "The index of the adjacency table needs to be a MultiIndex named "
                 "['focal', 'neighbor']."
@@ -136,6 +151,16 @@ class Graph(SetOpsMixin):
             )
         return self._adjacency.loc[item]
 
+    def __repr__(self):
+        if len(self.unique_ids) > 5:
+            unique_ids = f"{str(self.unique_ids[:5].tolist())[:-1]}, ...]"
+        else:
+            unique_ids = self.unique_ids.tolist()
+        return (
+            f"<Graph of {self.n} nodes and {self.nonzero} nonzero edges indexed by\n"
+            f" {unique_ids}>"
+        )
+
     def copy(self, deep=True):
         """Make a copy of this Graph's adjacency table and transformation
 
@@ -188,35 +213,58 @@ class Graph(SetOpsMixin):
         -------
         libpysal.weights.W
             representation of graph as a weights.W object
+
+        Examples
+        --------
+        >>> import geopandas as gpd
+        >>> from geodatasets import get_path
+        >>> nybb = gpd.read_file(get_path('nybb')).set_index("BoroName")
+        >>> nybb
+                       BoroCode  ...                                           geometry
+        BoroName                 ...
+        Staten Island         5  ...  MULTIPOLYGON (((970217.022 145643.332, 970227....
+        Queens                4  ...  MULTIPOLYGON (((1029606.077 156073.814, 102957...
+        Brooklyn              3  ...  MULTIPOLYGON (((1021176.479 151374.797, 102100...
+        Manhattan             1  ...  MULTIPOLYGON (((981219.056 188655.316, 980940....
+        Bronx                 2  ...  MULTIPOLYGON (((1012821.806 229228.265, 101278...
+        [5 rows x 4 columns]
+
+        >>> contiguity = graph.Graph.build_contiguity(nybb)
+        >>> contiguity.adjacency
+        focal          neighbor
+        Staten Island  Staten Island    0
+        Queens         Brooklyn         1
+                       Manhattan        1
+                       Bronx            1
+        Brooklyn       Queens           1
+                       Manhattan        1
+        Manhattan      Queens           1
+                       Brooklyn         1
+                       Bronx            1
+        Bronx          Queens           1
+                       Manhattan        1
+        Name: weight, dtype: int64
+
+        >>> w = contiguity.to_W()
+        >>> w.neighbors
+        {'Bronx': ['Queens', 'Manhattan'],
+         'Brooklyn': ['Queens', 'Manhattan'],
+         'Manhattan': ['Queens', 'Brooklyn', 'Bronx'],
+         'Queens': ['Brooklyn', 'Manhattan', 'Bronx'],
+         'Staten Island': []}
         """
-        ids, labels = pd.factorize(
-            self._adjacency.index.get_level_values("focal"), sort=False
-        )
-        neighbors = (
-            self._adjacency.reset_index(level=1)
-            .groupby(ids)
-            .apply(
-                lambda group: list(
-                    group[
-                        ~((group.index == group.neighbor) & (group.weight == 0))
-                    ].neighbor
-                )
-            )
-        )
-        neighbors.index = labels[neighbors.index]
-        weights = (
-            self._adjacency.reset_index(level=1)
-            .groupby(ids)
-            .apply(
-                lambda group: list(
-                    group[
-                        ~((group.index == group.neighbor) & (group.weight == 0))
-                    ].weight
-                )
-            )
-        )
-        weights.index = labels[weights.index]
-        return W(neighbors.to_dict(), weights.to_dict(), id_order=labels.tolist())
+        grouper = self._adjacency.groupby(level=0, sort=False)
+        neighbors = {}
+        weights = {}
+        for ix, chunk in grouper:
+            if ix in self.isolates:
+                neighbors[ix] = []
+                weights[ix] = []
+            else:
+                neighbors[ix] = chunk.index.get_level_values("neighbor").tolist()
+                weights[ix] = chunk.tolist()
+
+        return W(neighbors=neighbors, weights=weights, id_order=self.unique_ids)
 
     @classmethod
     def from_adjacency(
@@ -278,7 +326,9 @@ class Graph(SetOpsMixin):
             libpysal.graph.Graph based on sparse
         """
 
-        return cls.from_arrays(*_sparse_to_arrays(sparse, ids))
+        return cls(
+            _sparse_to_arrays(sparse, ids, return_adjacency=True), is_sorted=True
+        )
 
     @classmethod
     def from_arrays(cls, focal_ids, neighbor_ids, weight, **kwargs):
@@ -352,6 +402,51 @@ class Graph(SetOpsMixin):
         -------
         Graph
             libpysal.graph.Graph based on dictionaries
+
+        Examples
+        --------
+        >>> neighbors = {
+        ...     'Africa': ['Asia'],
+        ...     'Asia': ['Africa', 'Europe'],
+        ...     'Australia': [],
+        ...     'Europe': ['Asia'],
+        ...     'North America': ['South America'],
+        ...     'South America': ['North America'],
+        ... }
+        >>> connectivity = graph.Graph.from_dicts(neighbors)
+        >>> connectivity.adjacency
+        focal          neighbor
+        Africa         Asia             1
+        Asia           Africa           1
+                       Europe           1
+        Australia      Australia        0
+        Europe         Asia             1
+        North America  South America    1
+        South America  North America    1
+        Name: weight, dtype: float64
+
+        You can also specify weights (for example based
+        on the length of the shared border):
+
+        >>> weights = {
+        ...     'Africa': [1],
+        ...     'Asia': [0.2, 0.8],
+        ...     'Australia': [],
+        ...     'Europe': [1],
+        ...     'North America': [1],
+        ...     'South America': [1],
+        ... }
+        >>> connectivity = graph.Graph.from_dicts(neighbors, weights)
+        >>> connectivity.adjacency
+        focal          neighbor
+        Africa         Asia             1.0
+        Asia           Africa           0.2
+                       Europe           0.8
+        Australia      Australia        0.0
+        Europe         Asia             1.0
+        North America  South America    1.0
+        South America  North America    1.0
+        Name: weight, dtype: float64
         """
         head, tail, weight = _neighbor_dict_to_edges(neighbors, weights=weights)
         return cls.from_arrays(head, tail, weight)
@@ -375,6 +470,43 @@ class Graph(SetOpsMixin):
         -------
         Graph
             libpysal.graph.Graph encoding block contiguity
+
+        Examples
+        --------
+        >>> import geopandas as gpd
+        >>> from geodatasets import get_path
+        >>> france = gpd.read_file(get_path('geoda guerry')).set_index('Dprmnt')
+
+        In the GeoDa Guerry dataset, the Region column reflects the region
+        (North, East, West, South or Central) to which each department belongs.
+
+        >>> france[['Region', 'geometry']].head()
+                     Region                                           geometry
+        Dprtmnt
+        Ain               E  POLYGON ((801150.000 2092615.000, 800669.000 2...
+        Aisne             N  POLYGON ((729326.000 2521619.000, 729320.000 2...
+        Allier            C  POLYGON ((710830.000 2137350.000, 711746.000 2...
+        Basses-Alpes      E  POLYGON ((882701.000 1920024.000, 882408.000 1...
+        Hautes-Alpes      E  POLYGON ((886504.000 1922890.000, 885733.000 1...
+
+        Using the ``"Region"`` labels as ``regimes`` then identifies all departments
+        within the region as neighbors.
+
+        >>> block_contiguity = graph.Graph.build_block_contiguity(france['Region'])
+        >>> block_contiguity.adjacency
+        focal   neighbor
+        Ain     Basses-Alpes       1
+                Hautes-Alpes       1
+                Aube               1
+                Cote-d'Or          1
+                Doubs              1
+                                  ..
+        Vienne  Mayenne            1
+                Morbihan           1
+                Basses-Pyrenees    1
+                Deux-Sevres        1
+                Vendee             1
+        Name: weight, Length: 1360, dtype: int32
         """
         ids = _evaluate_index(regimes)
 
@@ -419,6 +551,56 @@ class Graph(SetOpsMixin):
         -------
         Graph
             libpysal.graph.Graph encoding contiguity weights
+
+        Examples
+        --------
+
+        >>> import geopandas as gpd
+        >>> from geodatasets import get_path
+        >>> nybb = gpd.read_file(get_path('nybb')).set_index("BoroName")
+        >>> nybb
+                       BoroCode  ...                                           geometry
+        BoroName                 ...
+        Staten Island         5  ...  MULTIPOLYGON (((970217.022 145643.332, 970227....
+        Queens                4  ...  MULTIPOLYGON (((1029606.077 156073.814, 102957...
+        Brooklyn              3  ...  MULTIPOLYGON (((1021176.479 151374.797, 102100...
+        Manhattan             1  ...  MULTIPOLYGON (((981219.056 188655.316, 980940....
+        Bronx                 2  ...  MULTIPOLYGON (((1012821.806 229228.265, 101278...
+        [5 rows x 4 columns]
+
+        >>> contiguity = graph.Graph.build_contiguity(nybb)
+        >>> contiguity.adjacency
+        focal          neighbor
+        Staten Island  Staten Island    0
+        Queens         Brooklyn         1
+                       Manhattan        1
+                       Bronx            1
+        Brooklyn       Queens           1
+                       Manhattan        1
+        Manhattan      Queens           1
+                       Brooklyn         1
+                       Bronx            1
+        Bronx          Queens           1
+                       Manhattan        1
+        Name: weight, dtype: int64
+
+        Weight by perimeter instead of binary weights:
+
+        >>> contiguity_perimeter = graph.Graph.build_contiguity(nybb, by_perimeter=True)
+        >>> contiguity_perimeter.adjacency
+        focal          neighbor
+        Staten Island  Staten Island        0.000000
+        Queens         Brooklyn         50867.502055
+                       Manhattan          103.745207
+                       Bronx                5.777002
+        Brooklyn       Queens           50867.502055
+                       Manhattan         5736.546898
+        Manhattan      Queens             103.745207
+                       Brooklyn          5736.546898
+                       Bronx             5258.300879
+        Bronx          Queens               5.777002
+                       Manhattan         5258.300879
+        Name: weight, dtype: float64
         """
         ids = _evaluate_index(geometry)
 
@@ -479,6 +661,96 @@ class Graph(SetOpsMixin):
         -------
         Graph
             libpysal.graph.Graph encoding distance band weights
+
+        Examples
+        --------
+        >>> import geopandas as gpd
+        >>> from geodatasets import get_path
+        >>> nybb = gpd.read_file(get_path('nybb')).set_index("BoroName")
+        >>> nybb
+                       BoroCode  ...                                           geometry
+        BoroName                 ...
+        Staten Island         5  ...  MULTIPOLYGON (((970217.022 145643.332, 970227....
+        Queens                4  ...  MULTIPOLYGON (((1029606.077 156073.814, 102957...
+        Brooklyn              3  ...  MULTIPOLYGON (((1021176.479 151374.797, 102100...
+        Manhattan             1  ...  MULTIPOLYGON (((981219.056 188655.316, 980940....
+        Bronx                 2  ...  MULTIPOLYGON (((1012821.806 229228.265, 101278...
+        [5 rows x 4 columns]
+
+        Note that the method requires point geometry (or an array of coordinates
+        representing points) as an input.
+
+        The threshold distance is in the units of the geometry projection.
+        You can check it using the ``nybb.crs`` property.
+
+        >>> distance_band = graph.Graph.build_distance_band(nybb.centroid, 45000)
+        >>> distance_band.adjacency
+        focal          neighbor
+        Staten Island  Staten Island    0
+        Queens         Brooklyn         1
+        Brooklyn       Queens           1
+        Manhattan      Bronx            1
+        Bronx          Manhattan        1
+        Name: weight, dtype: int64
+
+        The larger threshold yields more neighbors.
+
+        >>> distance_band = graph.Graph.build_distance_band(nybb.centroid, 110000)
+        >>> distance_band.adjacency
+        focal          neighbor
+        Staten Island  Queens           1
+                       Brooklyn         1
+                       Manhattan        1
+        Queens         Staten Island    1
+                       Brooklyn         1
+                       Manhattan        1
+                       Bronx            1
+        Brooklyn       Staten Island    1
+                       Queens           1
+                       Manhattan        1
+                       Bronx            1
+        Manhattan      Staten Island    1
+                       Queens           1
+                       Brooklyn         1
+                       Bronx            1
+        Bronx          Queens           1
+                       Brooklyn         1
+                       Manhattan        1
+        Name: weight, dtype: int64
+
+        Instead of binary weights you can use inverse distance.
+
+        >>> distance_band = graph.Graph.build_distance_band(
+        ...     nybb.centroid,
+        ...     45000,
+        ...     binary=False,
+        ... )
+        >>> distance_band.adjacency
+        focal          neighbor
+        Staten Island  Staten Island    0.000000
+        Queens         Brooklyn         0.000024
+        Brooklyn       Queens           0.000024
+        Manhattan      Bronx            0.000026
+        Bronx          Manhattan        0.000026
+        Name: weight, dtype: float64
+
+        Or specify the kernel function to derive weight from the distance.
+
+        >>> distance_band = graph.Graph.build_distance_band(
+        ...     nybb.centroid,
+        ...     45000,
+        ...     binary=False,
+        ...     kernel='bisquare',
+        ...     bandwidth=60000,
+        ... )
+        >>> distance_band.adjacency
+        focal          neighbor
+        Staten Island  Staten Island    0.000000
+        Queens         Brooklyn         0.232079
+        Brooklyn       Queens           0.232079
+        Manhattan      Bronx            0.309825
+        Bronx          Manhattan        0.309825
+        Name: weight, dtype: float64
         """
         ids = _evaluate_index(data)
 
@@ -602,7 +874,7 @@ class Graph(SetOpsMixin):
         bandwidth=None,
         metric="euclidean",
         p=2,
-        coincident="raise",
+        coplanar="raise",
     ):
         """Generate Graph from geometry data based on a kernel function
 
@@ -643,11 +915,11 @@ class Graph(SetOpsMixin):
             only euclidean, minkowski, and manhattan/cityblock distances are admitted.
         p : int (default: 2)
             parameter for minkowski metric, ignored if metric != "minkowski".
-        coincident: str, optional (default "raise")
-            Method for handling coincident points when ``k`` is not None. Options are
-            ``'raise'`` (raising an exception when coincident points are present),
-            ``'jitter'`` (randomly displace coincident points to produce uniqueness), &
-            ``'clique'`` (induce fully-connected sub cliques for coincident points).
+        coplanar: str, optional (default "raise")
+            Method for handling coplanar points when ``k`` is not None. Options are
+            ``'raise'`` (raising an exception when coplanar points are present),
+            ``'jitter'`` (randomly displace coplanar points to produce uniqueness), &
+            ``'clique'`` (induce fully-connected sub cliques for coplanar points).
 
         Returns
         -------
@@ -664,13 +936,13 @@ class Graph(SetOpsMixin):
             k=k,
             p=p,
             ids=ids,
-            coincident=coincident,
+            coplanar=coplanar,
         )
 
         return cls.from_arrays(head, tail, weight)
 
     @classmethod
-    def build_knn(cls, data, k, metric="euclidean", p=2, coincident="raise"):
+    def build_knn(cls, data, k, metric="euclidean", p=2, coplanar="raise"):
         """Generate Graph from geometry data based on k-nearest neighbors search
 
         Parameters
@@ -690,17 +962,64 @@ class Graph(SetOpsMixin):
             only euclidean, minkowski, and manhattan/cityblock distances are admitted.
         p : int (default: 2)
             parameter for minkowski metric, ignored if metric != "minkowski".
-        coincident: str, optional (default "raise")
-            Method for handling coincident points. Options include
-            ``'raise'`` (raising an exception when coincident points are present),
-            ``'jitter'`` (randomly displace coincident points to produce uniqueness), &
-            ``'clique'`` (induce fully-connected sub cliques for coincident points).
+        coplanar: str, optional (default "raise")
+            Method for handling coplanar points. Options include
+            ``'raise'`` (raising an exception when coplanar points are present),
+            ``'jitter'`` (randomly displace coplanar points to produce uniqueness), &
+            ``'clique'`` (induce fully-connected sub cliques for coplanar points).
 
 
         Returns
         -------
         Graph
             libpysal.graph.Graph encoding KNN weights
+
+        Examples
+        --------
+        >>> import geopandas as gpd
+        >>> from geodatasets import get_path
+        >>> nybb = gpd.read_file(get_path('nybb')).set_index('BoroName')
+        >>> nybb
+                       BoroCode  ...                                           geometry
+        BoroName                 ...
+        Staten Island         5  ...  MULTIPOLYGON (((970217.022 145643.332, 970227....
+        Queens                4  ...  MULTIPOLYGON (((1029606.077 156073.814, 102957...
+        Brooklyn              3  ...  MULTIPOLYGON (((1021176.479 151374.797, 102100...
+        Manhattan             1  ...  MULTIPOLYGON (((981219.056 188655.316, 980940....
+        Bronx                 2  ...  MULTIPOLYGON (((1012821.806 229228.265, 101278...
+
+        >>> knn3 = graph.Graph.build_knn(nybb.centroid, k=3)
+        >>> knn3.adjacency
+        focal           neighbor
+        Staten Island   Queens           1
+                        Brooklyn         1
+                        Manhattan        1
+        Queens          Brooklyn         1
+                        Manhattan        1
+                        Bronx            1
+        Brooklyn        Staten Island    1
+                        Queens           1
+                        Manhattan        1
+        Manhattan       Queens           1
+                        Brooklyn         1
+                        Bronx            1
+        Bronx           Queens           1
+                        Brooklyn         1
+                        Manhattan        1
+        Name: weight, dtype: int32
+
+        Specifying k=1 identifies the nearest neighbor
+        (note that this can be asymmetrical):
+
+        >>> knn1 = graph.Graph.build_knn(nybb.centroid, k=1)
+        >>> knn1.adjacency
+        focal          neighbor
+        Staten Island  Brooklyn     1
+        Queens         Brooklyn     1
+        Brooklyn       Queens       1
+        Manhattan      Bronx        1
+        Bronx          Manhattan    1
+        Name: weight, dtype: int32
         """
         ids = _evaluate_index(data)
 
@@ -712,7 +1031,7 @@ class Graph(SetOpsMixin):
             k=k,
             p=p,
             ids=ids,
-            coincident=coincident,
+            coplanar=coplanar,
         )
 
         return cls.from_arrays(head, tail, weight)
@@ -798,7 +1117,7 @@ class Graph(SetOpsMixin):
         kernel="boxcar",
         clip="bounding_box",
         rook=True,
-        coincident="raise",
+        coplanar="raise",
     ):
         """Generate Graph from geometry based on triangulation
 
@@ -846,34 +1165,72 @@ class Graph(SetOpsMixin):
             If True, two geometries are considered neighbours if they
             share at least one edge. If False, two geometries are considered neighbours
             if they share at least one vertex. By default True
-        coincident: str, optional (default "raise")
-            Method for handling coincident points. Options include
-            ``'raise'`` (raising an exception when coincident points are present),
-            ``'jitter'`` (randomly displace coincident points to produce uniqueness), &
-            ``'clique'`` (induce fully-connected sub cliques for coincident points).
+        coplanar: str, optional (default "raise")
+            Method for handling coplanar points. Options include
+            ``'raise'`` (raising an exception when coplanar points are present),
+            ``'jitter'`` (randomly displace coplanar points to produce uniqueness), &
+            ``'clique'`` (induce fully-connected sub cliques for coplanar points).
 
         Returns
         -------
         Graph
             libpysal.graph.Graph encoding triangulation weights
+
+        Examples
+        --------
+
+        >>> import geopandas as gpd
+        >>> from geodatasets import get_path
+        >>> nybb = gpd.read_file(get_path('nybb')).set_index("BoroName")
+        >>> nybb
+                       BoroCode  ...                                           geometry
+        BoroName                 ...
+        Staten Island         5  ...  MULTIPOLYGON (((970217.022 145643.332, 970227....
+        Queens                4  ...  MULTIPOLYGON (((1029606.077 156073.814, 102957...
+        Brooklyn              3  ...  MULTIPOLYGON (((1021176.479 151374.797, 102100...
+        Manhattan             1  ...  MULTIPOLYGON (((981219.056 188655.316, 980940....
+        Bronx                 2  ...  MULTIPOLYGON (((1012821.806 229228.265, 101278...
+        [5 rows x 4 columns]
+
+        Note that the method requires point geometry (or an array of coordinates
+        representing points) as an input.
+
+        >>> triangulation = graph.Graph.build_triangulation(nybb.centroid)
+        >>> triangulation.adjacency
+        focal          neighbor
+        Staten Island  Brooklyn         1
+                       Manhattan        1
+        Queens         Brooklyn         1
+                       Manhattan        1
+                       Bronx            1
+        Brooklyn       Staten Island    1
+                       Queens           1
+                       Manhattan        1
+        Manhattan      Staten Island    1
+                       Queens           1
+                       Brooklyn         1
+                       Bronx            1
+        Bronx          Queens           1
+                       Manhattan        1
+        Name: weight, dtype: int64
         """
         ids = _evaluate_index(data)
 
         if method == "delaunay":
             head, tail, weights = _delaunay(
-                data, ids=ids, bandwidth=bandwidth, kernel=kernel, coincident=coincident
+                data, ids=ids, bandwidth=bandwidth, kernel=kernel, coplanar=coplanar
             )
         elif method == "gabriel":
             head, tail, weights = _gabriel(
-                data, ids=ids, bandwidth=bandwidth, kernel=kernel, coincident=coincident
+                data, ids=ids, bandwidth=bandwidth, kernel=kernel, coplanar=coplanar
             )
         elif method == "relative_neighborhood":
             head, tail, weights = _relative_neighborhood(
-                data, ids=ids, bandwidth=bandwidth, kernel=kernel, coincident=coincident
+                data, ids=ids, bandwidth=bandwidth, kernel=kernel, coplanar=coplanar
             )
         elif method == "voronoi":
             head, tail, weights = _voronoi(
-                data, ids=ids, clip=clip, rook=rook, coincident=coincident
+                data, ids=ids, clip=clip, rook=rook, coplanar=coplanar
             )
         else:
             raise ValueError(
@@ -883,6 +1240,49 @@ class Graph(SetOpsMixin):
 
         return cls.from_arrays(head, tail, weights)
 
+    @classmethod
+    def build_h3(cls, ids, order=1, weight="distance"):
+        """Generate Graph from indices of H3 hexagons.
+
+        Encode a graph from a set of H3 hexagons. The graph is generated by
+        considering the H3 hexagons as nodes and connecting them based on their
+        contiguity. The contiguity is defined by the order parameter, which
+        specifies the number of steps to consider as neighbors. The weight
+        parameter defines the type of weight to assign to the edges.
+
+        Requires the `h3` library.
+
+        Parameters
+        ----------
+        ids : array-like
+            Array of H3 IDs encoding focal geometries
+        order : int, optional
+            Order of contiguity, by default 1
+        weight : str, optional
+            Type of weight. Options are:
+
+            * ``distance``: raw topological distance between cells
+            * ``binary``: 1 for neighbors, 0 for non-neighbors
+            * ``inverse``: 1 / distance between cells
+
+            By default "distance".
+
+        Returns
+        -------
+        Graph
+        """
+        neigbors, weights = _build_from_h3(ids, order=order)
+        g = cls.from_dicts(neigbors, weights)
+
+        if weight == "distance":
+            return g
+        elif weight == "binary":
+            return g.transform("b")
+        elif weight == "inverse":
+            return cls(1 / g._adjacency, is_sorted=True)
+        else:
+            raise ValueError("weight must be one of 'distance', 'binary', or 'inverse'")
+
     @cached_property
     def neighbors(self):
         """Get neighbors dictionary
@@ -897,18 +1297,14 @@ class Graph(SetOpsMixin):
         dict
             dict of tuples representing neighbors
         """
-        return (
-            self._adjacency.reset_index(level=1)
-            .groupby(level=0)
-            .apply(
-                lambda group: tuple(
-                    group[
-                        ~((group.index == group.neighbor) & (group.weight == 0))
-                    ].neighbor
-                )
-            )
-            .to_dict()
-        )
+        grouper = self._adjacency.groupby(level=0, sort=False)
+        neighbors = {}
+        for ix, chunk in grouper:
+            if ix in self.isolates:
+                neighbors[ix] = ()
+            else:
+                neighbors[ix] = tuple(chunk.index.get_level_values("neighbor"))
+        return neighbors
 
     @cached_property
     def weights(self):
@@ -924,30 +1320,26 @@ class Graph(SetOpsMixin):
         dict
             dict of tuples representing weights
         """
-        return (
-            self._adjacency.reset_index(level=1)
-            .groupby(level=0)
-            .apply(
-                lambda group: tuple(
-                    group[
-                        ~((group.index == group.neighbor) & (group.weight == 0))
-                    ].weight
-                )
-            )
-            .to_dict()
-        )
+        grouper = self._adjacency.groupby(level=0, sort=False)
+        weights = {}
+        for ix, chunk in grouper:
+            if ix in self.isolates:
+                weights[ix] = ()
+            else:
+                weights[ix] = tuple(chunk)
+        return weights
 
     @cached_property
     def sparse(self):
-        """Return a scipy.sparse array (COO)
+        """Return a scipy.sparse array (CSR)
 
         Returns
         -------
-        scipy.sparse.COO
+        scipy.sparse.CSR
             sparse representation of the adjacency
         """
-        # pivot to COO sparse matrix and cast to array
-        return sparse.coo_array(
+        # pivot to COO sparse matrix and cast to sparse CRS array
+        return sparse.csr_array(
             self._adjacency.astype("Sparse[float]").sparse.to_coo(sort_labels=True)[0]
         )
 
@@ -1022,8 +1414,7 @@ class Graph(SetOpsMixin):
     @cached_property
     def _components(self):
         """helper for n_components and component_labels"""
-        # TODO: remove casting to matrix once scipy supports arrays here
-        return sparse.csgraph.connected_components(sparse.coo_matrix(self.sparse))
+        return sparse.csgraph.connected_components(self.sparse)
 
     @cached_property
     def n_components(self):
@@ -1201,23 +1592,24 @@ class Graph(SetOpsMixin):
         Graph
             higher order weights
         """
-        # TODO: remove casting to matrix once scipy implements matrix_power on array.
-        # [https://github.com/scipy/scipy/pull/18544]
+        if not Version(scipy_version) >= Version("1.12.0"):
+            raise ImportError("Graph.higher_order() requires scipy>=1.12.0.")
+
         binary = self.transform("B")
-        sp = sparse.csr_matrix(binary.sparse)
+        sp = binary.sparse
 
         if lower_order:
-            wk = sum(sp**x for x in range(2, k + 1))
+            wk = sum(sparse.linalg.matrix_power(sp, x) for x in range(2, k + 1))
             shortest_path = False
         else:
-            wk = sp**k
+            wk = sparse.linalg.matrix_power(sp, k)
 
         rk, ck = wk.nonzero()
         sk = set(zip(rk, ck, strict=True))
 
         if shortest_path:
             for j in range(1, k):
-                wj = sp**j
+                wj = sparse.linalg.matrix_power(sp, j)
                 rj, cj = wj.nonzero()
                 sj = set(zip(rj, cj, strict=True))
                 sk.difference_update(sj)
@@ -1235,24 +1627,37 @@ class Graph(SetOpsMixin):
             ids=self.unique_ids,
         )
 
-    def lag(self, y):
+    def lag(self, y, categorical=False, ties="raise"):
         """Spatial lag operator
 
-        If weights are row standardized, returns the mean of each
-        observation's neighbors; if not, returns the weighted sum
-        of each observation's neighbors.
+        Constructs spatial lag based on neighbor relations of the graph.
+
 
         Parameters
         ----------
-        y : array-like
-            array-like (N,) shape where N is equal to number of observations in self.
+        y : array
+            numpy array with dimensionality conforming to w
+        categorical : bool
+            True if y is categorical, False if y is continuous.
+        ties : {'raise', 'random', 'tryself'}, optional
+            Policy on how to break ties when a focal unit has multiple
+            modes for a categorical lag.
+            - 'raise': This will raise an exception if ties are
+            encountered to alert the user (Default).
+            - 'random': modal label ties Will be broken randomly.
+            - 'tryself': check if focal label breaks the tie between label
+            modes.  If the focal label does not break the modal tie, the
+            tie will be be broken randomly. If the focal unit has a
+            self-weight, focal label is not used to break any tie,
+            rather any tie will be broken randomly.
+
 
         Returns
         -------
         numpy.ndarray
-            array of numeric values for the spatial lag
+            array of numeric|categorical values for the spatial lag
         """
-        return _lag_spatial(self, y)
+        return _lag_spatial(self, y, categorical=categorical, ties=ties)
 
     def to_parquet(self, path, **kwargs):
         """Save Graph to a Apache Parquet
@@ -1275,6 +1680,38 @@ class Graph(SetOpsMixin):
         """
         _to_parquet(self, path, **kwargs)
 
+    def to_gal(self, path):
+        """Save Graph to a GAL file
+
+        Graph is serialized to the GAL file format.
+
+        Parameters
+        ----------
+        path : str
+            path to the GAL file
+
+        See also
+        --------
+        read_gal
+        """
+        _to_gal(self, path)
+
+    def to_gwt(self, path):
+        """Save Graph to a GWT file
+
+        Graph is serialized to the GWT file format.
+
+        Parameters
+        ----------
+        path : str
+            path to the GWT file
+
+        See also
+        --------
+        read_gwt
+        """
+        _to_gwt(self, path)
+
     def to_networkx(self):
         """Convert Graph to a ``networkx`` graph.
 
@@ -1581,6 +2018,72 @@ class Graph(SetOpsMixin):
         """
         return self._adjacency.groupby(level=0).agg(func)
 
+    def describe(
+        self,
+        y,
+        q=None,
+        statistics=None,
+    ):
+        """Describe the distribution of ``y`` values within the neighbors of each node.
+
+        Given the graph, computes the descriptive statistics of values within the
+        neighbourhood of each node. Optionally, the values can be limited to a certain
+        quantile range before computing the statistics.
+
+        Notes
+        -----
+        The index of ``values`` must match the index of the graph.
+
+        Weight values do not affect the calculations, only adjacency does.
+
+        Returns numpy.nan for all isolates.
+
+        The numba package is used extensively in this function
+        to accelerate the computation of statistics.
+        Without numba, these computations may become slow on large data.
+
+        Parameters
+        ----------
+        y : NDArray[np.float64] | Series
+            An 1D array of numeric values to be described.
+        q : tuple[float, float] | None, optional
+            Tuple of percentages for the percentiles to compute.
+            Values must be between 0 and 100 inclusive. When set, values below and above
+            the percentiles will be discarded before computation of the statistics.
+            The percentiles are computed for each neighborhood. By default None.
+        statistics : list[str] | None
+            A list of stats functions to compute. If None, compute all
+            available functions - "count", "mean", "median",
+            "std", "min", "max", "sum", "nunique", "mode". By default None.
+
+        Returns
+        -------
+        DataFrame
+            A DataFrame with descriptive statistics.
+        """
+
+        if not isinstance(y, pd.Series):
+            y = pd.Series(y, index=self.unique_ids)
+
+        if (y.index != self.unique_ids).all():
+            raise ValueError("The values index is not aligned with the graph index.")
+
+        if q is None:
+            grouper = y.take(self._adjacency.index.codes[1]).groupby(
+                self._adjacency.index.codes[0]
+            )
+        else:
+            grouper = _percentile_filtration_grouper(y, self._adjacency.index, q=q)
+
+        stat_ = _compute_stats(grouper, statistics)
+
+        stat_.index = self.unique_ids
+        if isinstance(stat_, pd.Series):
+            stat_.name = None
+        # NA isolates
+        stat_.loc[self.isolates] = np.nan
+        return stat_
+
 
 def _arrange_arrays(heads, tails, weights, ids=None):
     """
@@ -1630,3 +2133,40 @@ def read_parquet(path, **kwargs):
     """
     adjacency, transformation = _read_parquet(path, **kwargs)
     return Graph(adjacency, transformation, is_sorted=True)
+
+
+def read_gal(path):
+    """Read Graph from a GAL file
+
+    The reader tries to infer the dtype of IDs. In case of unsuccessful
+    casting to int, it will fall back to string.
+
+    Parameters
+    ----------
+    path : str
+        path to a file
+
+    Returns
+    -------
+    Graph
+        deserialized Graph
+    """
+    neighbors = _read_gal(path)
+    return Graph.from_dicts(neighbors)
+
+
+def read_gwt(path):
+    """Read Graph from a GWT file
+
+    Parameters
+    ----------
+    path : str
+        path to a file
+
+    Returns
+    -------
+    Graph
+        deserialized Graph
+    """
+    head, tail, weight = _read_gwt(path)
+    return Graph.from_arrays(head, tail, weight)
