@@ -7,6 +7,8 @@ import geopandas as gpd
 import numpy as np
 import pandas as pd
 import pytest
+from packaging.version import Version
+from scipy import __version__ as scipy_version
 from scipy import sparse
 
 from libpysal import graph, weights
@@ -91,6 +93,7 @@ class TestBase:
         self.g_str_unodered = graph.Graph.from_weights_dict(self.W_dict_str_unordered)
 
         self.nybb = gpd.read_file(geodatasets.get_path("nybb")).set_index("BoroName")
+        self.guerry = gpd.read_file(geodatasets.get_path("geoda guerry"))
 
     def test_init(self):
         g = graph.Graph(self.adjacency_int_binary)
@@ -135,6 +138,26 @@ class TestBase:
         with pytest.raises(ValueError, match="'transformation' needs to be"):
             graph.Graph(self.adjacency_int_binary, transformation="foo")
 
+    def test___repr__(self):
+        expected = (
+            "<Graph of 10 nodes and 25 nonzero edges indexed by\n"
+            " [0, 1, 2, 3, 4, ...]>"
+        )
+        assert repr(self.g_int) == expected
+
+        expected = (
+            "<Graph of 10 nodes and 25 nonzero edges indexed by\n"
+            " ['a', 'b', 'c', 'd', 'e', ...]>"
+        )
+        assert repr(self.g_str) == expected
+
+        nybb = graph.Graph.build_contiguity(self.nybb)
+        expected = (
+            "<Graph of 5 nodes and 10 nonzero edges indexed by\n"
+            " ['Staten Island', 'Queens', 'Brooklyn', 'Manhattan', 'Bronx']>"
+        )
+        assert repr(nybb) == expected
+
     def test_copy(self):
         g_copy = self.g_str.copy()
         assert g_copy == self.g_str
@@ -824,6 +847,32 @@ class TestBase:
             g_pandas = graph.read_parquet(path)
             assert self.g_str == g_pandas
 
+    def test_gal(self):
+        with tempfile.TemporaryDirectory() as tmpdir:
+            path = os.path.join(tmpdir, "g_int.gal")
+            g_int = self.g_int.transform("b")
+            g_int.to_gal(path)
+            g_int_ = graph.read_gal(path)
+            assert g_int == g_int_
+
+            path = os.path.join(tmpdir, "g_str.gal")
+            g_str = self.g_str.transform("b")
+            g_str.to_gal(path)
+            g_str_ = graph.read_gal(path)
+            assert g_str == g_str_
+
+    def test_gwt(self):
+        with tempfile.TemporaryDirectory() as tmpdir:
+            path = os.path.join(tmpdir, "g_int.gwt")
+            self.g_int.to_gwt(path)
+            g_int = graph.read_gwt(path)
+            assert self.g_int == g_int
+
+            path = os.path.join(tmpdir, "g_str.gwt")
+            self.g_str.to_gwt(path)
+            g_str = graph.read_gwt(path)
+            assert self.g_str == g_str
+
     def test_getitem(self):
         expected = pd.Series(
             [1, 0.5, 0.5],
@@ -856,6 +905,10 @@ class TestBase:
         with pytest.raises(ValueError, match="The length of `y`"):
             self.g_str.lag(list(range(1, 15)))
 
+    @pytest.mark.skipif(
+        Version(scipy_version) < Version("1.12.0"),
+        reason="sparse matrix power requires scipy>=1.12.0",
+    )
     def test_higher_order(self):
         cont = graph.Graph.build_contiguity(self.nybb)
         k2 = cont.higher_order(2)
@@ -1097,3 +1150,94 @@ class TestBase:
             contig.aggregate(lambda x: np.exp(np.sum(x))),
             expected,
         )
+
+    def test_describe(self):
+        contig = graph.Graph.build_knn(self.guerry.geometry.centroid, k=5)
+        y = self.guerry.geometry.area
+        stats = contig.describe(y)
+        pd.testing.assert_series_equal(
+            stats["count"],
+            contig.cardinalities,
+            check_names=False,
+            check_dtype=False,
+        )
+        pd.testing.assert_series_equal(
+            stats["sum"],
+            pd.Series(contig.lag(y), index=contig.unique_ids),
+            check_names=False,
+        )
+        r_contig = contig.transform("R")
+        pd.testing.assert_series_equal(
+            stats["mean"],
+            pd.Series(r_contig.lag(y), index=contig.unique_ids),
+            check_names=False,
+        )
+        ## compute only some statistics
+        specific_stats = contig.describe(y, statistics=["count", "sum", "mean"])
+        ## assert only the specified values are computed
+        assert list(specific_stats.columns) == ["count", "sum", "mean"]
+
+        pd.testing.assert_frame_equal(
+            specific_stats[["count", "sum", "mean"]], stats[["count", "sum", "mean"]]
+        )
+
+        percentile_stats = contig.describe(y, q=(25, 75))
+
+        for i in contig.unique_ids:
+            neigh_vals = y[contig[i].index.values]
+            low, high = neigh_vals.describe()[["25%", "75%"]]
+            neigh_vals = neigh_vals[(low <= neigh_vals) & (neigh_vals <= high)]
+            expected = neigh_vals.describe()[["count", "mean", "std", "min", "max"]]
+            res = percentile_stats.loc[i][["count", "mean", "std", "min", "max"]]
+            pd.testing.assert_series_equal(res, expected, check_names=False)
+
+        ## test NA equivalence between filtration and pandas
+        nan_areas = y.copy()
+        nan_areas.iloc[range(0, len(y), 3),] = np.nan
+        res1 = contig.describe(y, statistics=["count"])["count"]
+        res2 = contig.describe(y, statistics=["count"], q=(0, 100))["count"]
+        pd.testing.assert_series_equal(res1, res2)
+
+        # test with isolates and string index
+        nybb_contig = graph.Graph.build_contiguity(self.nybb, rook=False)
+        stats = nybb_contig.describe(
+            self.nybb.geometry.area, statistics=["count", "sum"]
+        )
+        ## all isolate values should be nan
+        assert stats.loc["Staten Island"].isna().all()
+
+        # for easier comparison and na has already been checked.
+        stats = stats.fillna(0)
+
+        pd.testing.assert_series_equal(
+            stats["sum"],
+            pd.Series(nybb_contig.lag(self.nybb.geometry.area), index=self.nybb.index),
+            check_names=False,
+        )
+
+        pd.testing.assert_series_equal(
+            stats["count"].sort_index(),
+            nybb_contig.cardinalities.sort_index(),
+            check_dtype=False,
+            check_names=False,
+        )
+
+        ## test passing ndarray
+        stats1 = nybb_contig.describe(self.nybb.geometry.area, statistics=["sum"])[
+            "sum"
+        ]
+        stats2 = nybb_contig.describe(
+            self.nybb.geometry.area.values, statistics=["sum"]
+        )["sum"]
+        pd.testing.assert_series_equal(
+            stats1,
+            stats2,
+            check_dtype=False,
+            check_names=False,
+        )
+
+        ## test index alignment
+        with pytest.raises(
+            ValueError, match="The values index is not aligned with the graph index."
+        ):
+            nybb_contig.describe(self.nybb.geometry.area.reset_index(drop=True))
