@@ -190,6 +190,23 @@ class TestTriangulation:
                 self.gdf, method="invalid", kernel="parabolic", bandwidth=7500
             )
 
+    def test_delunay_subsets(self):
+        delaunay = graph.Graph.build_triangulation(
+            self.gdf_str, "delaunay", kernel="identity"
+        )
+        gabriel = graph.Graph.build_triangulation(
+            self.gdf_str, "gabriel", kernel="identity"
+        )
+        rn = graph.Graph.build_triangulation(
+            self.gdf_str, "relative_neighborhood", kernel="identity"
+        )
+        pd.testing.assert_series_equal(
+            gabriel.adjacency, delaunay.adjacency.loc[gabriel.adjacency.index]
+        )
+        pd.testing.assert_series_equal(
+            rn.adjacency, delaunay.adjacency.loc[rn.adjacency.index]
+        )
+
 
 class TestKernel:
     def setup_method(self):
@@ -248,14 +265,14 @@ class TestKernel:
         assert pd.api.types.is_numeric_dtype(g._adjacency.dtype)
 
     def test_knn_intids(self):
-        g = graph.Graph.build_knn(self.gdf, k=3, coincident="jitter")
+        g = graph.Graph.build_knn(self.gdf, k=3, coplanar="jitter")
 
         assert pd.api.types.is_numeric_dtype(g._adjacency.index.dtypes["focal"])
         assert pd.api.types.is_numeric_dtype(g._adjacency.index.dtypes["neighbor"])
         assert pd.api.types.is_numeric_dtype(g._adjacency.dtype)
 
     def test_knn_strids(self):
-        g = graph.Graph.build_kernel(self.gdf_str, k=3, coincident="jitter")
+        g = graph.Graph.build_kernel(self.gdf_str, k=3, coplanar="jitter")
 
         assert pd.api.types.is_string_dtype(g._adjacency.index.dtypes["focal"])
         assert pd.api.types.is_string_dtype(g._adjacency.index.dtypes["neighbor"])
