@@ -97,10 +97,10 @@ class TestSetOps:
 
     def test___eq__(self):
         assert self.distance2500 == self.distance2500.copy()
-        assert not self.distance2500 == self.distance2500_id  # noqa SIM201
+        assert not self.distance2500 == self.distance2500_id  # noqa: SIM201
 
     def test___ne__(self):
-        assert not self.distance2500 != self.distance2500.copy()  # noqa SIM202
+        assert not self.distance2500 != self.distance2500.copy()  # noqa: SIM202
         assert self.distance2500 != self.distance2500_id
 
     def test___and__(self):
