@@ -1,3 +1,5 @@
+# ruff: noqa: B006, N802, N803, N813
+
 import itertools
 import warnings
 
@@ -6,12 +8,13 @@ import numpy
 from ..cg import voronoi_frames
 from ..io.fileio import FileIO
 from ._contW_lists import ContiguityWeightsLists
+from .raster import da2W, da2WSP
 from .util import get_ids, get_points_array
 from .weights import WSP, W
-from .raster import da2W, da2WSP
 
 try:
     from shapely.geometry import Point as shapely_point
+
     from ..cg.shapes import Point as pysal_point
 
     point_type = (shapely_point, pysal_point)
@@ -27,7 +30,8 @@ __all__ = ["Rook", "Queen", "Voronoi"]
 
 class Rook(W):
     """
-    Construct a weights object from a collection of pysal polygons that share at least one edge.
+    Construct a weights object from a collection of pysal
+    polygons that share at least one edge.
 
     Parameters
     ----------
@@ -49,8 +53,10 @@ class Rook(W):
         polygons, backup = itertools.tee(polygons)
         first_shape = next(iter(backup))
         if isinstance(first_shape, point_type):
-            polygons, vertices = voronoi_frames(get_points_array(polygons))
-            polygons = list(polygons.geometry)
+            polygons = voronoi_frames(
+                get_points_array(polygons), return_input=False, as_gdf=False
+            )
+            polygons = list(polygons)
         neighbors, ids = _build(polygons, criterion=criterion, ids=ids)
         W.__init__(self, neighbors, ids=ids, **kw)
 
@@ -61,7 +67,6 @@ class Rook(W):
 
         Parameters
         ----------
-
         shapefile : string
                     name of polygon shapefile including suffix.
         sparse    : boolean
@@ -70,7 +75,6 @@ class Rook(W):
 
         Returns
         -------
-
         w          : W
                      instance of spatial weights
 
@@ -81,7 +85,9 @@ class Rook(W):
         >>> wr=Rook.from_shapefile(libpysal.examples.get_path("columbus.shp"), "POLYID")
         >>> "%.3f"%wr.pct_nonzero
         '8.330'
-        >>> wr=Rook.from_shapefile(libpysal.examples.get_path("columbus.shp"), sparse=True)
+        >>> wr=Rook.from_shapefile(
+        ...     libpysal.examples.get_path("columbus.shp"), sparse=True
+        ... )
         >>> pct_sp = wr.sparse.nnz *1. / wr.n**2
         >>> "%.3f"%pct_sp
         '0.083'
@@ -98,10 +104,7 @@ class Rook(W):
         :class:`libpysal.weights.contiguity.Rook`
         """
         sparse = kwargs.pop("sparse", False)
-        if idVariable is not None:
-            ids = get_ids(filepath, idVariable)
-        else:
-            ids = None
+        ids = get_ids(filepath, idVariable) if idVariable is not None else None
         w = cls(FileIO(filepath), ids=ids, **kwargs)
         w.set_shapefile(filepath, idVariable=idVariable, full=full)
         if sparse:
@@ -121,6 +124,7 @@ class Rook(W):
                       support iteration. Can be either Shapely or PySAL shapes.
         **kw        : keyword arguments
                       optional arguments for  :class:`pysal.weights.W`
+
         See Also
         --------
         :class:`libpysal.weights.weights.W`
@@ -251,7 +255,7 @@ class Rook(W):
         coords_labels={},
         k=1,
         include_nodata=False,
-        n_jobs=1,
+        n_jobs=1,  # noqa: ARG003
         sparse=True,
         **kwargs,
     ):
@@ -269,10 +273,12 @@ class Rook(W):
         coords_labels : dictionary
             Pass dimension labels for coordinates and layers if they do not
             belong to default dimensions, which are (band/time, y/lat, x/lon)
-            e.g. coords_labels = {"y_label": "latitude", "x_label": "longitude", "z_label": "year"}
+            e.g. coords_labels = {"y_label": "latitude",
+            "x_label": "longitude", "z_label": "year"}
             Default is {} empty dictionary.
         sparse : boolean
-            type of weight object. Default is True. For libpysal.weights.W, sparse = False
+            type of weight object. Default is True.
+            For libpysal.weights.W, sparse = False
         k : int
             Order of contiguity, this will select all neighbors upto kth order.
             Default is 1.
@@ -310,7 +316,8 @@ class Rook(W):
 
 class Queen(W):
     """
-    Construct a weights object from a collection of pysal polygons that share at least one vertex.
+    Construct a weights object from a collection of pysal
+    polygons that share at least one vertex.
 
     Parameters
     ----------
@@ -332,8 +339,10 @@ class Queen(W):
         polygons, backup = itertools.tee(polygons)
         first_shape = next(iter(backup))
         if isinstance(first_shape, point_type):
-            polygons, vertices = voronoi_frames(get_points_array(polygons))
-            polygons = list(polygons.geometry)
+            polygons = voronoi_frames(
+                get_points_array(polygons), return_input=False, as_gdf=False
+            )
+            polygons = list(polygons)
         neighbors, ids = _build(polygons, criterion=criterion, ids=ids)
         W.__init__(self, neighbors, ids=ids, **kw)
 
@@ -344,7 +353,6 @@ class Queen(W):
 
         Parameters
         ----------
-
         shapefile   : string
                       name of polygon shapefile including suffix.
         idVariable  : string
@@ -352,9 +360,9 @@ class Queen(W):
         sparse      : boolean
                       If True return WSP instance
                       If False return W instance
+
         Returns
         -------
-
         w            : W
                        instance of spatial weights
 
@@ -368,13 +376,15 @@ class Queen(W):
         >>> wq=Queen.from_shapefile(libpysal.examples.get_path("columbus.shp"),"POLYID")
         >>> "%.3f"%wq.pct_nonzero
         '9.829'
-        >>> wq=Queen.from_shapefile(libpysal.examples.get_path("columbus.shp"), sparse=True)
+        >>> wq=Queen.from_shapefile(
+        ...     libpysal.examples.get_path("columbus.shp"), sparse=True
+        ... )
         >>> pct_sp = wq.sparse.nnz *1. / wq.n**2
         >>> "%.3f"%pct_sp
         '0.098'
 
         Notes
-
+        -----
         Queen contiguity defines as neighbors any pair of polygons that share at
         least one vertex in their polygon definitions.
 
@@ -384,10 +394,7 @@ class Queen(W):
         :class:`libpysal.weights.contiguity.Queen`
         """
         sparse = kwargs.pop("sparse", False)
-        if idVariable is not None:
-            ids = get_ids(filepath, idVariable)
-        else:
-            ids = None
+        ids = get_ids(filepath, idVariable) if idVariable is not None else None
         w = cls(FileIO(filepath), ids=ids, **kwargs)
         w.set_shapefile(filepath, idVariable=idVariable, full=full)
         if sparse:
@@ -403,10 +410,12 @@ class Queen(W):
         Parameters
         ----------
         iterable    : iterable
-                      a collection of of shapes to be cast to PySAL shapes. Must
-                      support iteration. Contents may either be a shapely or PySAL shape.
+                      a collection of of shapes to be cast to PySAL shapes.
+                      Must support iteration. Contents may either be
+                      a shapely or PySAL shape.
         **kw        : keyword arguments
                       optional arguments for  :class:`pysal.weights.W`
+
         See Also
         ---------
         :class:`libpysal.weights.weights.W`
@@ -537,7 +546,7 @@ class Queen(W):
         coords_labels={},
         k=1,
         include_nodata=False,
-        n_jobs=1,
+        n_jobs=1,  # noqa: ARG003
         sparse=True,
         **kwargs,
     ):
@@ -555,10 +564,12 @@ class Queen(W):
         coords_labels : dictionary
             Pass dimension labels for coordinates and layers if they do not
             belong to default dimensions, which are (band/time, y/lat, x/lon)
-            e.g. coords_labels = {"y_label": "latitude", "x_label": "longitude", "z_label": "year"}
+            e.g. coords_labels = {"y_label": "latitude", "x_label":
+            "longitude", "z_label": "year"}
             Default is {} empty dictionary.
         sparse : boolean
-            type of weight object. Default is True. For libpysal.weights.W, sparse = False
+            type of weight object. Default is True.
+            For libpysal.weights.W, sparse = False
         k : int
             Order of contiguity, this will select all neighbors upto kth order.
             Default is 1.
@@ -594,17 +605,14 @@ class Queen(W):
         return w
 
 
-def Voronoi(points, criterion="rook", clip="ahull", **kwargs):
+def Voronoi(points, criterion="rook", clip="alpha_shape", **kwargs):
     """
     Voronoi weights for a 2-d point set
 
-
     Points are Voronoi neighbors if their polygons share an edge or vertex.
 
-
     Parameters
     ----------
-
     points      : array
                   (n,2)
                   coordinates for point locations
@@ -612,7 +620,6 @@ def Voronoi(points, criterion="rook", clip="ahull", **kwargs):
 
     Returns
     -------
-
     w           : W
                   instance of spatial weights
 
@@ -628,15 +635,15 @@ def Voronoi(points, criterion="rook", clip="ahull", **kwargs):
     """
     from ..cg.voronoi import voronoi_frames
 
-    region_df, _ = voronoi_frames(points, clip=clip)
+    region_df = voronoi_frames(points, clip=clip, return_input=False, as_gdf=True)
     if criterion.lower() == "queen":
         cls = Queen
     elif criterion.lower() == "rook":
         cls = Rook
     else:
         raise ValueError(
-            "Contiguity criterion {} not supported. "
-            'Only "rook" and "queen" are supported.'.format(criterion)
+            f"Contiguity criterion {criterion} not supported. "
+            "Only 'rook' and 'queen' are supported."
         )
     return cls.from_dataframe(region_df, **kwargs)
 
@@ -668,7 +675,7 @@ def _from_dataframe(df, **kwargs):
             "Voronoi weights are only"
             " implemented for point geometries. "
             "You may consider using df.centroid."
-        )
+        ) from None
     coords = numpy.column_stack((x, y))
     return Voronoi(coords, **kwargs)
 
@@ -685,7 +692,8 @@ def _build(polygons, criterion="rook", ids=None):
     polygons    : list
                   list of pysal polygons to use to build contiguity
     criterion   : string
-                  option of which kind of contiguity to build. Is either "rook" or "queen"
+                  option of which kind of contiguity to build.
+                  Is either "rook" or "queen"
     ids         : list
                   list of ids to use to index the neighbor dictionary
 
@@ -695,10 +703,12 @@ def _build(polygons, criterion="rook", ids=None):
     describing contiguity relations and ids is the list of ids used to index
     that dictionary.
 
-    NOTE: this is different from the prior behavior of buildContiguity, which
-          returned an actual weights object. Since this just dispatches for the
-          classes above, this returns the raw ingredients for a spatial weights
-          object, not the object itself.
+    Notes
+    -----
+    This is different from the prior behavior of buildContiguity, which
+    returned an actual weights object. Since this just dispatches for the
+    classes above, this returns the raw ingredients for a spatial weights
+    object, not the object itself.
     """
     if ids and len(ids) != len(set(ids)):
         raise ValueError(
@@ -727,7 +737,13 @@ def _build(polygons, criterion="rook", ids=None):
             neighbors[key] = set(neighbor_data[key])
     return (
         dict(
-            list(zip(list(neighbors.keys()), list(map(list, list(neighbors.values())))))
+            list(
+                zip(
+                    list(neighbors.keys()),
+                    list(map(list, list(neighbors.values()))),
+                    strict=True,
+                )
+            )
         ),
         ids,
     )
@@ -747,4 +763,4 @@ def buildContiguity(polygons, criterion="rook", ids=None):
     elif criterion.lower() == "queen":
         return Queen(polygons, ids=ids)
     else:
-        raise Exception('Weights criterion "{}" was not found.'.format(criterion))
+        raise ValueError(f"Weights criterion '{criterion}' was not found.")
